==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/bathroom/dialogs_nl.lua <==

dialogId("br-v-komfort", "font_big", "It`s quite comfortable for a wasteyard.")
dialogStr("Wel comfortabel voor een vuilnisbelt.")


dialogId("br-m-bydli", "font_small", "What do you think, does anybody live here?")
dialogStr("Denk je dat hier iemand woont?")


dialogId("br-v-santusak", "font_big", "Some underwater homeless.")
dialogStr("Misschien een onderwaterdakloze.")


dialogId("br-m-podvodnik", "font_small", "We call them shell-less.")
dialogStr("Dat noemen we hier een schelploze.")


dialogId("br-m-vsim0", "font_small", "Did you notice that...")
dialogStr("Is het je opgevallen dat...")


dialogId("br-m-vsim1", "font_small", "Don`t you think that...")
dialogStr("Zou je denken dat...")


dialogId("br-m-vsim2", "font_small", "Isn`t it strange that...")
dialogStr("Is het niet gek dat...")


dialogId("br-v-nerozvadet0", "font_big", "Don`t talk about it.")
dialogStr("Hou je mond!")


dialogId("br-v-nerozvadet1", "font_big", "Please, no jokes about defecation.")
dialogStr("Alsjeblieft, geen grapjes meer over stoelgang.")


dialogId("br-v-nerozvadet2", "font_big", "Yes, I know about that. We won`t comment on it.")
dialogStr("Ja, ik weet het. We zeggen niks.")


dialogId("br-m-dva", "font_small", "Yeah, but why TWO?")
dialogStr("Ja, maar waarom twee?")


dialogId("br-v-dost", "font_big", "Stop it, will you?")
dialogStr("Hou alsjeblieft op!")


dialogId("br-m-sprcha", "font_small", "I`ve seen many useless things, but an underwater shower...")
dialogStr("Ik heb al een hoop nutteloze dingen gezien, maar een onderwater douche slaat echt alles.")


dialogId("br-v-lazen", "font_big", "Maybe it sprays air, like in the bubble bath.")
dialogStr("Misschien sproeit die lucht, net als in een bubbelbad.")


dialogId("br-m-zapnout", "font_small", "Do you think we could turn it on?")
dialogStr("Denk je dat we hem aan kunnen zetten?")


dialogId("br-v-shodit", "font_big", "Hardly. But we could push it down.")
dialogStr("Nou nee. Maar we zouden hem naar beneden kunnen duwen.")


dialogId("br-m-poklady", "font_small", "Now this is real treasure.")
dialogStr("Dit is pas een echte schat!")


dialogId("br-v-nechat", "font_big", "We should have left it alone.")
dialogStr("We hadden van dat ding af moeten blijven.")


dialogId("br-m-nefunguje", "font_small", "And it doesn`t work anyway.")
dialogStr("En hij doet het ook al niet.")


dialogId("br-m-ahoj", "font_small", "Hello, inside there.")
dialogStr("Hallo daar binnen!.")


dialogId("br-v-draha", "font_big", "This must be better than a rollercoaster.")
dialogStr("Dat is vast leuker dan een achtbaan.")


dialogId("br-m-zkusit", "font_small", "I would love to try it myself.")
dialogStr("Dat zou ik graag eens willen uitproberen.")


dialogId("br-m-bavi", "font_small", "He seems to be enjoying himself.")
dialogStr("Hij vermaakt zich wel.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/bathroom/dialogs_nl.lua <==

dialogId("br-v-komfort", "font_big", "It’s quite comfortable for a wasteyard.")
dialogStr("Wel comfortabel voor een vuilnisbelt.")


dialogId("br-m-bydli", "font_small", "What do you think, does anybody live here?")
dialogStr("Denk je dat hier iemand woont?")


dialogId("br-v-santusak", "font_big", "Some underwater homeless.")
dialogStr("Misschien een onderwaterdakloze.")


dialogId("br-m-podvodnik", "font_small", "We call them shell-less.")
dialogStr("Dat noemen we hier een schelploze.")


dialogId("br-m-vsim0", "font_small", "Did you notice that...")
dialogStr("Is het je opgevallen dat...")


dialogId("br-m-vsim1", "font_small", "Don’t you think that...")
dialogStr("Zou je denken dat...")


dialogId("br-m-vsim2", "font_small", "Isn’t it strange that...")
dialogStr("Is het niet gek dat...")


dialogId("br-v-nerozvadet0", "font_big", "Don’t talk about it.")
dialogStr("Hou je mond!")


dialogId("br-v-nerozvadet1", "font_big", "Please, no jokes about defecation.")
dialogStr("Alsjeblieft, geen grapjes meer over stoelgang.")


dialogId("br-v-nerozvadet2", "font_big", "Yes, I know about that. We won’t comment on it.")
dialogStr("Ja, ik weet het. We zeggen niks.")


dialogId("br-m-dva", "font_small", "Yeah, but why TWO?")
dialogStr("Ja, maar waarom TWEE?")


dialogId("br-v-dost", "font_big", "Stop it, will you?")
dialogStr("Hou alsjeblieft op!")


dialogId("br-m-sprcha", "font_small", "I’ve seen many useless things, but an underwater shower...")
dialogStr("Ik heb al een hoop nutteloze dingen gezien, maar een onderwaterdouche slaat echt alles.")


dialogId("br-v-lazen", "font_big", "Maybe it sprays air, like in the bubble bath.")
dialogStr("Misschien sproeit die lucht, net als in een bubbelbad.")


dialogId("br-m-zapnout", "font_small", "Do you think we could turn it on?")
dialogStr("Denk je dat we hem aan zouden kunnen zetten?")


dialogId("br-v-shodit", "font_big", "Hardly. But we could push it down.")
dialogStr("Nou nee. Maar we zouden hem naar beneden kunnen duwen.")


dialogId("br-m-poklady", "font_small", "Now this is real treasure.")
dialogStr("Dit is pas een echte schat!")


dialogId("br-v-nechat", "font_big", "We should have left it alone.")
dialogStr("We hadden van dat ding af moeten blijven.")


dialogId("br-m-nefunguje", "font_small", "And it doesn’t work anyway.")
dialogStr("En hij doet het toch niet.")


dialogId("br-m-ahoj", "font_small", "Hello, inside there.")
dialogStr("Hallo daarbinnen!.")


dialogId("br-v-draha", "font_big", "This must be better than a rollercoaster.")
dialogStr("Dat is vast leuker dan een achtbaan.")


dialogId("br-m-zkusit", "font_small", "I would love to try it myself.")
dialogStr("Dat zou ik graag zelf eens willen uitproberen.")


dialogId("br-m-bavi", "font_small", "He seems to be enjoying himself.")
dialogStr("Zo te zien vermaakt hij zich wel.")
